@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2012 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 5838 2013-03-19 01:55:24Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -108,12 +108,15 @@ class BaseFrameContainer extends Core
 			$canAccess = true;		// アクセス可能かどうか
 			$isErrorAccess = false;		// 不正アクセスかどうか
 			$toAdminType = 0;		// 管理画面の遷移タイプ(0=アクセス不可、1=ログイン画面、2=サイト非公開画面, 3=存在しないページ)
+			$errMessage = '';	// エラーメッセージ
+			$messageDetail = '';	// 詳細メッセージ
 			
 			// ページID,ページサブIDからアクセス権をチェック
 			$isPublicUrl = $this->gPage->canAccessUrl($isActivePage);
 			if (!$isPublicUrl && !$isSystemManageUser){// システム運用可能ユーザかどうか
 				$canAccess = false;
 				$isErrorAccess = true;		// 不正アクセスかどうか
+				$errMessage = 'ユーザに公開されていないページへのアクセス。';
 				
 				if (!$isActivePage) $toAdminType = 3;		// 有効なアクセスポイントでない場合は存在しないページとする
 			}
@@ -154,6 +157,8 @@ class BaseFrameContainer extends Core
 							// 標準のアクセスでは、上記コマンド以外は受け付けない
 							$canAccess = false;
 							$isErrorAccess = true;		// 不正アクセス
+							$errMessage = '不正なコマンドの実行。';
+							$messageDetail = 'アクセスポイント状態=公開';
 						}
 					} else {		// サイトアクセスできない場合は、管理画面でメッセージを表示
 						if ($cmd == M3_REQUEST_CMD_LOGIN ||					// ログイン画面を表示のとき
@@ -177,6 +182,8 @@ class BaseFrameContainer extends Core
 							$cmd != M3_REQUEST_CMD_RSS){		// RSS配信
 							
 							$isErrorAccess = true;		// 不正アクセス
+							$errMessage = '不正なコマンドの実行。';
+							$messageDetail = 'アクセスポイント状態=非公開';
 						}
 					}
 				}
@@ -199,8 +206,15 @@ class BaseFrameContainer extends Core
 					case 2:			// サイト非公開画面へ
 						$this->gPage->setSystemHandleMode(10/*サイト非公開中*/);
 						break;
-					case 3:			// 存在しないページ画面へ
-						$this->gPage->setSystemHandleMode(12/*存在しないページ*/);
+					case 3:			// 存在しないページ画面へ(システム運用可能ユーザ以外)
+						// サイトが非公開の場合は、メンテナンス中画面のみ表示
+						if ($this->_accessSite($request)){		// サイト公開中の場合
+							$messageDetail = 'アクセスポイント状態=公開';
+							$this->gPage->setSystemHandleMode(12/*存在しないページ*/);
+						} else {
+							$messageDetail = 'アクセスポイント状態=非公開';
+							$this->gPage->setSystemHandleMode(10/*サイト非公開中*/);
+						}
 						break;
 					default:		// アクセス不可画面へ
 						// システム制御モードに変更
@@ -211,7 +225,7 @@ class BaseFrameContainer extends Core
 				$this->_showSystemPage($request, $toAdminType);
 						
 				// 不正アクセスの場合は、アクセスエラーログを残す
-				if ($isErrorAccess) $this->gOpeLog->writeUserAccess(__METHOD__, '不正なアクセスを検出しました。', 2200, 'アクセスをブロックしました。URL: ' . $this->gEnv->getCurrentRequestUri());
+				if ($isErrorAccess) $this->gOpeLog->writeUserAccess(__METHOD__, '不正なアクセスを検出しました。' . $errMessage, 2200, 'アクセスをブロックしました。URL: ' . $this->gEnv->getCurrentRequestUri() . ', ' . $messageDetail);
 				return;
 			}
 			// #################### URLの遷移 #######################
@@ -324,6 +338,10 @@ class BaseFrameContainer extends Core
 						$this->gCache->setPageCache($request, $pageData);		// キャッシュデータを設定
 						echo $pageData;
 					} else {		// 管理者以外で、非共通のウィジェットが使用されていないページはアクセス不可とする
+						$errMessage = 'ユーザに公開されていないページへのアクセス。';
+						$messageDetail = 'アクセスポイント状態=公開, 要因: 共有ウィジェットのみのページへのアクセスは不可。';
+						$this->gOpeLog->writeUserAccess(__METHOD__, '不正なアクセスを検出しました。' . $errMessage, 2200, 'アクセスをブロックしました。URL: ' . $this->gEnv->getCurrentRequestUri() . ', ' . $messageDetail);
+
 						// アクセス不可ページへ遷移
 						$this->gPage->redirect('?' . M3_REQUEST_PARAM_PAGE_SUB_ID . '=_accessdeny');
 						// システム制御モードに変更
@@ -719,7 +737,8 @@ class BaseFrameContainer extends Core
 		// ########### テンプレートID(ディレクトリ名)を設定 ############
 		// テンプレートIDの指定の方法は2パターン
 		// 　1.サブクラスで固定に指定
-		// 　2.セッションに保持
+		// 　2.コンテンツからの指定
+		// 　3.セッションに保持
 		// テンプレートIDの優先順位
 		// 　1.サブクラスの_setTemplate()で固定設定にしている場合の固定値
 		// 　2.セッションに持っている値
@@ -736,15 +755,15 @@ class BaseFrameContainer extends Core
 		}
 
 		// サブクラスでテンプレートIDを指定している場合はそちらを使用
-		$isSubclassDefined = false;		// サブクラスでの固定かどうか
+		$templateDefined = false;		// テンプレート固定かどうか
 		if ($useSubClassDefine){
 			$tmplStr = trim($this->_setTemplate($request));
 			if (strlen($tmplStr) > 0){
 				$curTemplate = $tmplStr;
-				$isSubclassDefined = true;		// サブクラスでの固定かどうか
+				$templateDefined = true;		// テンプレート固定かどうか
 			}
 		}
-		
+
 		// セッションにあるときは、セッションの値を使用(携帯でないとき)
 		$pageId = $request->trimValueOf(M3_REQUEST_PARAM_DEF_PAGE_ID);
 		if ($curTemplate == ''){
@@ -778,6 +797,12 @@ class BaseFrameContainer extends Core
 						$curTemplate = $request->getSessionValue(M3_SESSION_CURRENT_TEMPLATE);// 携帯サイト、スマートフォンサイトでないときはセッション値を取得
 					}
 				}
+				// オプションのテンプレートがある場合はオプションを優先
+				$optionTemplate = $this->gPage->getOptionTemplateId();
+				if (!empty($optionTemplate)){
+					$curTemplate = $optionTemplate;
+					$templateDefined = true;		// テンプレート固定かどうか
+				}
 			}
 		}
 
@@ -796,9 +821,9 @@ class BaseFrameContainer extends Core
 			} else {
 				$curTemplate = $pageTemplateId;
 			}
-			// オプションのテンプレートがある場合はオプションを優先
-			$optionTemplate = $this->gPage->getOptionTemplateId();
-			if (!empty($optionTemplate)) $curTemplate = $optionTemplate;
+//			// オプションのテンプレートがある場合はオプションを優先
+//			$optionTemplate = $this->gPage->getOptionTemplateId();
+//			if (!empty($optionTemplate)) $curTemplate = $optionTemplate;
 		}
 		
 		if ($curTemplate == ''){
@@ -812,7 +837,7 @@ class BaseFrameContainer extends Core
 				if ($cmd == M3_REQUEST_CMD_SHOW_POSITION ||				// 表示位置を表示するとき
 					$cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET){	// 表示位置を表示するとき(ウィジェット付き)
 				} else {
-					if (!$this->gEnv->getIsMobileSite() && !$this->gEnv->getIsSmartphoneSite() && !$isSubclassDefined){		// PC用画面でサブクラス固定でないとき場合は保存
+					if (!$this->gEnv->getIsMobileSite() && !$this->gEnv->getIsSmartphoneSite() && !$templateDefined){		// PC用画面でサブクラス固定でないとき場合は保存
 						$request->setSessionValue(M3_SESSION_CURRENT_TEMPLATE, $curTemplate);
 					}
 				}
