@@ -62,7 +62,7 @@ INSERT INTO blog_config
 ('category_count',          '2',         '記事に設定可能なカテゴリ数',         10),
 ('entry_default_image',      '0_72c.jpg;0_200c.jpg', '記事デフォルト画像', 0),
 ('comment_user_limited',      '0',       'コメントのユーザ制限',                 0),
-('layout_entry_single',   '[#TITLE#]<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#LINKS#]', 'コンテンツレイアウト(記事詳細)',               0),
+('layout_entry_single',   '<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#LINKS#]', 'コンテンツレイアウト(記事詳細)',               0),
 ('layout_entry_list',   '[#TITLE#]<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#COMMENT_LINK#]', 'コンテンツレイアウト(記事一覧)',               0),
 ('layout_comment_list',   '[#AVATAR#]<dl><db>[#TITLE#] <small>[#CM_AUTHOR#] [#CM_DATE#] [#CM_TIME#] [#URL#]</small></dt><dd>[#BODY#]</dd></dl>', 'コンテンツレイアウト(コメント一覧)',               0),
 ('output_head',      '0', 'HTMLヘッダ出力', 0),
@@ -77,7 +77,7 @@ INSERT INTO blog_config
 ('s:jquery_view_style',       '1',      'jQueryMobile表示スタイル',           104),
 ('s:use_title_list_image',       '1',      'タイトルリスト画像を使用',           105),
 ('s:title_list_image',       '',      'タイトルリスト画像',           106),
-('s:layout_entry_single',   '[#TITLE#]<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#LINKS#]', 'コンテンツレイアウト(記事詳細)',               100),
+('s:layout_entry_single',   '<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#LINKS#]', 'コンテンツレイアウト(記事詳細)',               100),
 ('s:layout_entry_list',   '[#TITLE#]<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#COMMENT_LINK#]', 'コンテンツレイアウト(記事一覧)',               100),
 ('s:layout_comment_list', '[#AVATAR#]<dl><db>[#TITLE#] <small>[#CM_AUTHOR#] [#CM_DATE#] [#CM_TIME#] [#URL#]</small></dt><dd>[#BODY#]</dd></dl>', 'コンテンツレイアウト(コメント一覧)',               0),
 ('s:output_head',      '0', 'HTMLヘッダ出力', 100),
@@ -219,12 +219,12 @@ INSERT INTO _templates
 
 -- メニューIDマスター
 INSERT INTO _menu_id
-(mn_id,         mn_name,          mn_description, mn_device_type, mn_sort_order) VALUES
-('main_menu',   'メインメニュー(PC用)', '',             0,              0),
-('sub_menu1',   'サブメニュー1(PC用)',  '',             0,              1),
-('sub_menu2',   'サブメニュー2(PC用)',  '',             0,              2),
-('sub_menu3',   'サブメニュー3(PC用)',  '',             0,              3),
-('s_main_menu', 'メインメニュー(スマートフォン用)', '',             2,              0);
+(mn_id,         mn_name,          mn_description, mn_device_type, mn_widget_id, mn_sort_order) VALUES
+('main_menu',   'メインメニュー(PC用)', '',             0,        '',      0),
+('sub_menu1',   'サブメニュー1(PC用)',  '',             0,        '',      1),
+('sub_menu2',   'サブメニュー2(PC用)',  '',             0,        '',      2),
+('sub_menu3',   'サブメニュー3(PC用)',  '',             0,        '',      3),
+('s_main_menu', 'メインメニュー(スマートフォン用)', '',             2,     '',         0);
 
 -- 基本テーブルの不要なデータを削除
 -- 画面定義
