@@ -32,14 +32,12 @@ $HELP['menu_name_input']['title'] = '名前';
 $HELP['menu_name_input']['body'] = 'メニュー設定名です。新規に登録するか、登録済みの設定を選択します。';
 $HELP['menu_id']['title'] = 'メニュー設定ID';
 $HELP['menu_id']['body'] = '自動的に振られるメニュー設定IDです。';
-$HELP['menu_show_title']['title'] = 'タイトル表示';
-$HELP['menu_show_title']['body'] = 'メニューにタイトルを表示するかどうかを設定します。タイトルは「名前」が使用されます。';
 $HELP['menu_limit_user']['title'] = 'ユーザ制限';
 $HELP['menu_limit_user']['body'] = 'メニューの表示をログインしたユーザに限定するかどうかを設定します。';
 $HELP['menu_design']['title'] = 'デザイン';
 $HELP['menu_design']['body'] = '●縦型メニュー<br />Artisteer 2.4から使用可能な「縦型メニュー」のデザインを使用するかどうかを設定します。';
 $HELP['menu_def']['title'] = 'メニュー定義';
-$HELP['menu_def']['body'] = 'メニュー項目で使用するメニュー定義を選択します。定義データはシステムで共通です。<br />1階層でメニューを定義するか、多階層でメニューを定義するかを選択します。<br />メニューIDは管理機能の「システムマスター管理/メニュー」で管理します。';
+$HELP['menu_def']['body'] = 'メニュー項目で使用するメニュー定義を選択します。定義データはシステムで共通です。<br />単階層でメニューを定義するか、多階層でメニューを定義するかを選択します。<br />メニューIDは管理機能の「システムマスター管理/メンテナンス/マスター管理/メニューID」で管理します。';
 $HELP['menu_ref']['title'] = '使用';
 $HELP['menu_ref']['body'] = 'メニュー設定を使用しているウィジェット数を示します。使用が0のメニュー設定のみ削除可能です。';
 $HELP['menu_list_btn']['title'] = '一覧ボタン';
