@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: update_entities.inc.php 1147 2008-10-28 04:00:59Z fishbone $
+ * @version    SVN: $Id: update_entities.inc.php 1601 2009-03-21 05:51:06Z fishbone $
  * @link       http://www.magic3.org
  */
 // Update entities plugin - Update XHTML entities from DTD
@@ -63,30 +63,18 @@ function plugin_update_entities_action()
 		$body  = convert_html(sprintf($_entities_messages['msg_usage'], join("\n" . '-', $items)));
 		$postScript = $script . WikiParam::convQuery("?");
 		$body .= <<<EOD
-<form action="$postScript" method="post">
+<form action="$postScript" method="post" class="form">
  <div>
   <input type="hidden" name="plugin" value="update_entities" />
   <input type="hidden" name="action" value="update" />
   <input type="hidden" name="pass" />
   <label for="_p_update_entities_adminpass">{$_entities_messages['msg_adminpass']}</label>
   <input type="password" name="password" id="_p_update_entities_adminpass" size="12" />
-  <input type="submit" value="{$_entities_messages['btn_submit']}" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
+  <input type="submit" class="button" value="{$_entities_messages['btn_submit']}" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
  </div>
 </form>
 EOD;
-/*
-		$body .= <<<EOD
-<form method="POST" action="$script">
- <div>
-  <input type="hidden" name="plugin" value="update_entities" />
-  <input type="hidden" name="action" value="update" />
-  <label for="_p_update_entities_adminpass">{$_entities_messages['msg_adminpass']}</label>
-  <input type="password" name="adminpass" id="_p_update_entities_adminpass" size="20" value="" />
-  <input type="submit" value="{$_entities_messages['btn_submit']}" />
- </div>
-</form>
-EOD;
-*/
+
 	//} else if ($vars['action'] == 'update') {
 	} else if ($action == 'update') {
 		plugin_update_entities_create(TRUE);
